Further reading
===============

Mighty fine documementation, the stuff you're reading now. But some other
suggestions, ideas and a different tone might help you improve your firewall.
So here are some pointers to other material.

